package net.knarcraft.serverlauncher.profile;

import net.knarcraft.serverlauncher.server.Server;
import net.knarcraft.serverlauncher.userinterface.GUI;

import javax.swing.*;
import java.io.IOException;
import java.util.ArrayList;

/**
 * Contains all user settings
 *
 * @author		Kristian Knarvik <kristian.knarvik@knett.no>
 * @version	0.0.0.1
 * @since		0.0.0.1
 */
public class Profile {
    private static final ArrayList<Profile> profiles = new ArrayList<>();

    private final ArrayList<Server> servers;
    private final String name;
    private boolean runInBackground;
    private int delayStartup;
    private boolean downloadJars;
    private String vanillaVersion;
    private String snapshotVersion;
    private String spongeVanillaVersion;
    private String bungeeVersion;

    private Profile(String name) {
        this.servers = new ArrayList<>();
        this.name = name;
        this.runInBackground = false;
        this.delayStartup = 0;
        this.downloadJars = false;
        profiles.add(this);
    }

    public void addServer(Server server) {
        this.servers.add(server);
    }

    public void removeServer(int i) {
        this.servers.remove(i);
    }

    private Server getServer(String name) {
        for (Server server : this.servers) {
            if (server.getName().equals(name)) {
                return server;
            }
        }
        return null;
    }

    public boolean serverExists(String name) {
        for (Server server : this.servers) {
            if (server.getName().equals(name)) {
                return true;
            }
        }
        return false;
    }

    public ArrayList<Server> getServers() {
        return this.servers;
    }

    public static void addProfile(String name) {
        if (name == null) { //If a user cancels or crosses out window
            return;
        }
        if (name.equals("")) {
            JOptionPane.showMessageDialog(null, "Profile name can't be blank.", "Error", JOptionPane.ERROR_MESSAGE);
            return;
        }
        for (Profile profile : profiles) {
            if (profile.name.equals(name)) {
                JOptionPane.showMessageDialog(null, "There is already a profile with this name.", "Error", JOptionPane.ERROR_MESSAGE);
                return;
            }
        }
        new Profile(name);
        GUI.getGUI().addProfile(name);
    }

    public static Profile getProfile(String name) {
        for (Profile profile : profiles) {
            if (profile.name.equals(name)) {
                return profile;
            }
        }
        return null;
    }

    public static void deleteProfile(String name) {
        if (profiles.size() > 1) {
            for (int i = 0; i < profiles.size(); i++) {
                if (profiles.get(i).name.equals((name))) {
                    profiles.remove(i);
                    GUI.getGUI().removeProfile(i);
                }
            }
        }
    }

    public void setRunInBackground(boolean value) {
        this.runInBackground = value;
    }

    public void setDelayStartup(int value) {
        if (value >= 0) {
            this.delayStartup = value;
        }
    }

    public void setDownloadJars(boolean value) {
        this.downloadJars = value;
    }

    public void sendCommand(String serverName, String command) {
        if (serverName.equals("All")) {
            for (Server server : this.servers) {
                try {
                    server.sendCommand(command);
                } catch (IOException e) {
                    JOptionPane.showMessageDialog(null, "Server " + server.getName() + " caused an exception.", "Error", JOptionPane.ERROR_MESSAGE);
                }
            }
        } else {
            Server target = getServer(serverName);
            if (target != null) {
                try {
                    target.sendCommand(command);
                } catch (IOException e) {
                    JOptionPane.showMessageDialog(null, "Server " + target.getName() + " caused an exception.", "Error", JOptionPane.ERROR_MESSAGE);
                }
            } else {
                JOptionPane.showMessageDialog(null, "Server " + serverName + " is invalid.", "Error", JOptionPane.ERROR_MESSAGE);
            }
        }
    }
}
